0.5.15 (2023-10-26)
-------------------
- Improve get_absolute_url() usage
- Improve default_value on Filter()

0.5.14 (2023-10-24)
-------------------
- Add default_value on Filter()

0.5.12 (2023-10-19)
-------------------
- Improve foreign key column title
- Fix word search with filter_queryset_method

0.5.10 (2023-10-12)
-------------------
- Fix listing export for Excel

0.5.9 (2023-09-26)
------------------
- Better focus when using Select2 widget

0.5.8 (2023-09-22)
------------------
- Strip HTML tags on data exports

0.5.7 (2023-09-21)
------------------
- Fix exception management for Django 4
- Add add_one_day option on DateFilter

0.5.5 (2023-09-07)
------------------
- Fix unexpected SQL query with ListingVariations

0.5.4 (2023-09-06)
------------------
- Data Export works with active filters and ajax=True

0.5.3 (2023-08-23)
------------------
- Add filter_queryset_method filter attribute

0.5.2 (2023-08-08)
------------------
- Update fr translations

0.5.1 (2023-07-06)
------------------
- Add links in ManyColumn if get_absolute_url() exists on related objects

0.5.0 (2023-07-05)
------------------
- Add __url_func parameter for edit/delete/view action buttons

0.0.28 (2023-06-27)
-------------------
- Add AutocompleteMultipleForeignKeyFilter

0.0.27 (2023-06-26)
-------------------
- Add ForeignKeyFilter and AutocompleteForeignKeyFilter

0.0.26 (2023-06-21)
-------------------
- Added edit and delete action buttons
- Fixed action button "see details" modal

0.0.24 (2023-06-20)
-------------------
- Improved CSS for small device
- Auto-detect many-to-many model fields if present in select_columns

0.0.23 (2023-06-19)
-------------------
- Fixed choices widgets

0.0.22 (2023-06-19)
-------------------
- Improved radio and checkbox in filter form

0.0.21 (2023-06-15)
-------------------
- Fixed ModelColumns

0.0.20 (2023-05-19)
-------------------
- Added LineNumberColumn()

0.0.18 (2023-05-05)
-------------------
- Use scss to generate css files

0.0.17 (2023-04-26)
-------------------
- Added showcase with many demo pages see showcase/README.rst

0.0.14 (2022-10-24)
-------------------
- Fixed bad form closing
- Fixed ListingVariation with Ajax

0.0.12 (2022-07-04)
-------------------
- Added django-like filter syntax for sequences

0.0.11 (2022-06-02)
-------------------
- Added JsonDateTimeColumn class

0.0.10 (2022-05-17)
-------------------
- Added support for python 3.10

0.0.9 (2021-11-09)
------------------
- Added possibility to create custom action button linked with listing method

0.0.7 (2020-07-14)
------------------
- First running version

0.0.1 (2018-02-03)
------------------
- Skeleton commit
